@@ -14,17 +14,22 @@
 package cli
 
 import (
+	"fmt"
+
 	"github.com/dustin/go-humanize"
 	"github.com/nats-io/natscli/columns"
 )
 
-func newColumns(heading string, a ...any) *columns.Writer {
-	w := columns.New(heading, a...)
+func newColumns(heading string) *columns.Writer {
+	w := columns.New(heading)
 	w.SetColorScheme(opts().Config.ColorScheme())
-	w.SetHeading(heading, a...)
+	w.SetHeading(heading)
 
 	return w
 }
+func newColumnsf(heading string, a ...any) *columns.Writer {
+	return newColumns(fmt.Sprintf(heading, a...))
+}
 
 func fiBytes(v uint64) string {
 	return humanize.IBytes(v)
@@ -34,6 +39,10 @@ func f(v any) string {
 	return columns.F(v)
 }
 
+func fFloatFixedDecimal(v any) string {
+	return humanize.FormatFloat("#,###.##", v.(float64))
+}
+
 func fFloat2Int(v any) string {
 	return columns.F(uint64(v.(float64)))
 }
