@@ -122,9 +122,11 @@ type consumerCmd struct {
 	pinnedGroups       []string
 	pinnedTTL          time.Duration
 	overflowGroups     []string
+	prioritizedGroups  []string
 	groupName          string
 	fPinned            bool
 	placementPreferred string
+	apiLevel           int
 }
 
 func configureConsumerCommand(app commandHost) {
@@ -136,9 +138,9 @@ func configureConsumerCommand(app commandHost) {
 			f.Flag("bps", "Restrict message delivery to a certain bit per second").Default("0").Uint64Var(&c.bpsRateLimit)
 		}
 		f.Flag("backoff", "Creates a consumer backoff policy using a specific pre-written algorithm (none, linear)").PlaceHolder("MODE").EnumVar(&c.backoffMode, "linear", "none")
-		f.Flag("backoff-steps", "Number of steps to use when creating the backoff policy").PlaceHolder("STEPS").Default("10").UintVar(&c.backoffSteps)
-		f.Flag("backoff-min", "The shortest backoff period that will be generated").PlaceHolder("MIN").Default("1m").DurationVar(&c.backoffMin)
-		f.Flag("backoff-max", "The longest backoff period that will be generated").PlaceHolder("MAX").Default("20m").DurationVar(&c.backoffMax)
+		f.Flag("backoff-steps", "Number of steps to use when creating the backoff policy").Default("10").UintVar(&c.backoffSteps)
+		f.Flag("backoff-min", "The shortest backoff period that will be generated").Default("1m").DurationVar(&c.backoffMin)
+		f.Flag("backoff-max", "The longest backoff period that will be generated").Default("20m").DurationVar(&c.backoffMax)
 		if !edit {
 			f.Flag("deliver", "Start policy (all, new, last, subject, 1h, msg sequence)").PlaceHolder("POLICY").StringVar(&c.startPolicy)
 			f.Flag("deliver-group", "Delivers push messages only to subscriptions matching this group").Default("_unset_").PlaceHolder("GROUP").StringVar(&c.deliveryGroup)
@@ -178,9 +180,10 @@ func configureConsumerCommand(app commandHost) {
 		f.Flag("metadata", "Adds metadata to the consumer").PlaceHolder("META").IsSetByUser(&c.metadataIsSet).StringMapVar(&c.metadata)
 		if !edit {
 			f.Flag("pause", fmt.Sprintf("Pause the consumer for a duration after start or until a specific timestamp (eg %s)", time.Now().Format(time.DateTime))).StringVar(&c.pauseUntil)
-			f.Flag("pinned-groups", "Create a Pinned Client consumer based on these groups").StringsVar(&c.pinnedGroups)
-			f.Flag("pinned-ttl", "The time to allow for a client to pull before losing the pinned status").DurationVar(&c.pinnedTTL)
-			f.Flag("overflow-groups", "Create a Overflow consumer based on these groups").StringsVar(&c.overflowGroups)
+			f.Flag("pinned-groups", "Create a Pinned Client consumer based on these groups").PlaceHolder("GROUPS").StringsVar(&c.pinnedGroups)
+			f.Flag("pinned-ttl", "The time to allow for a client to pull before losing the pinned status").PlaceHolder("TTL").DurationVar(&c.pinnedTTL)
+			f.Flag("overflow-groups", "Create a Overflow consumer based on these groups").PlaceHolder("GROUPS").StringsVar(&c.overflowGroups)
+			f.Flag("prioritized-groups", "Create a Prioritized consumer based on these groups").PlaceHolder("GROUPS").StringsVar(&c.prioritizedGroups)
 		}
 	}
 
@@ -227,6 +230,7 @@ func configureConsumerCommand(app commandHost) {
 	consFind.Flag("pinned", "Finds Pinned Client priority group consumers that are fully pinned").UnNegatableBoolVar(&c.fPinned)
 	consFind.Flag("invert", "Invert the check - before becomes after, with becomes without").BoolVar(&c.fInvert)
 	consFind.Flag("expression", "Match consumers using an expression language").StringVar(&c.fExpression)
+	consFind.Flag("api-level", "Match consumers that support at least the given api level").IntVar(&c.apiLevel)
 
 	consInfo := cons.Command("info", "Consumer information").Alias("nfo").Action(c.infoAction)
 	consInfo.Arg("stream", "Stream name").StringVar(&c.stream)
@@ -433,6 +437,9 @@ func (c *consumerCmd) findAction(_ *fisk.ParseContext) error {
 	if c.fPinned {
 		opts = append(opts, jsm.ConsumerQueryIsPinned())
 	}
+	if c.apiLevel > 0 {
+		opts = append(opts, jsm.ConsumerQueryApiLevelMin(c.apiLevel))
+	}
 
 	found, err := stream.QueryConsumers(opts...)
 	if err != nil {
@@ -493,8 +500,8 @@ func (c *consumerCmd) graphAction(_ *fisk.ParseContext) error {
 	ackedRates := make([]float64, width)
 	outstandingMessages := make([]float64, width)
 	unprocessedMessages := make([]float64, width)
-	lastAckedSeq := nfo.AckFloor.Stream
-	lastDeliveredSeq := nfo.Delivered.Stream
+	lastAckedSeq := nfo.AckFloor.Consumer
+	lastDeliveredSeq := nfo.Delivered.Consumer
 	lastStateTs := time.Now()
 
 	ticker := time.NewTicker(time.Second)
@@ -522,12 +529,12 @@ func (c *consumerCmd) graphAction(_ *fisk.ParseContext) error {
 				continue
 			}
 
-			deliveredRates = append(deliveredRates, calculateRate(float64(nfo.Delivered.Stream), float64(lastDeliveredSeq), time.Since(lastStateTs)))
-			ackedRates = append(ackedRates, calculateRate(float64(nfo.AckFloor.Stream), float64(lastAckedSeq), time.Since(lastStateTs)))
+			deliveredRates = append(deliveredRates, calculateRate(float64(nfo.Delivered.Consumer), float64(lastDeliveredSeq), time.Since(lastStateTs)))
+			ackedRates = append(ackedRates, calculateRate(float64(nfo.AckFloor.Consumer), float64(lastAckedSeq), time.Since(lastStateTs)))
 			unprocessedMessages = append(unprocessedMessages, float64(nfo.NumPending))
 			outstandingMessages = append(outstandingMessages, float64(nfo.NumAckPending))
-			lastDeliveredSeq = nfo.Delivered.Stream
-			lastAckedSeq = nfo.AckFloor.Stream
+			lastDeliveredSeq = nfo.Delivered.Consumer
+			lastAckedSeq = nfo.AckFloor.Consumer
 			lastStateTs = time.Now()
 
 			deliveredRates = resizeData(deliveredRates, width)
@@ -541,7 +548,7 @@ func (c *consumerCmd) graphAction(_ *fisk.ParseContext) error {
 				asciigraph.Height(height/4-2),
 				asciigraph.LowerBound(0),
 				asciigraph.Precision(0),
-				asciigraph.ValueFormatter(f),
+				asciigraph.ValueFormatter(fFloatFixedDecimal),
 			)
 
 			ackedPlot := asciigraph.Plot(ackedRates,
@@ -550,7 +557,7 @@ func (c *consumerCmd) graphAction(_ *fisk.ParseContext) error {
 				asciigraph.Height(height/4-2),
 				asciigraph.LowerBound(0),
 				asciigraph.Precision(0),
-				asciigraph.ValueFormatter(f),
+				asciigraph.ValueFormatter(fFloatFixedDecimal),
 			)
 
 			unprocessedPlot := asciigraph.Plot(unprocessedMessages,
@@ -1052,10 +1059,10 @@ func (c *consumerCmd) lsAction(pc *fisk.ParseContext) error {
 
 func (c *consumerCmd) renderConsumerAsTable(stream *jsm.Stream) (string, error) {
 	var out bytes.Buffer
-	table := iu.NewTableWriter(opts(), "Consumers")
+	table := iu.NewTableWriterf(opts(), "Consumers")
 	table.AddHeaders("Name", "Description", "Created", "Ack Pending", "Unprocessed", "Last Delivery")
 
-	missing, err := stream.EachConsumer(func(cons *jsm.Consumer) {
+	missing, offline, err := stream.EachConsumer(func(cons *jsm.Consumer) {
 		cs, err := cons.LatestState()
 		if err != nil {
 			log.Printf("Could not obtain consumer state for %s: %s", cons.Name(), err)
@@ -1076,8 +1083,8 @@ func (c *consumerCmd) renderConsumerAsTable(stream *jsm.Stream) (string, error)
 
 	fmt.Fprintln(&out, table.Render())
 
-	if len(missing) > 0 {
-		c.renderMissing(&out, missing)
+	if len(missing) > 0 || len(offline) > 0 {
+		c.renderMissing(&out, missing, offline)
 	}
 
 	return out.String(), nil
@@ -1125,9 +1132,9 @@ func (c *consumerCmd) showInfo(config api.ConsumerConfig, state api.ConsumerInfo
 
 	var cols *columns.Writer
 	if c.showStateOnly {
-		cols = newColumns(fmt.Sprintf("State for Consumer %s > %s created %s", state.Stream, state.Name, state.Created.Local().Format(time.RFC3339)))
+		cols = newColumnsf("State for Consumer %s > %s created %s", state.Stream, state.Name, f(state.Created))
 	} else {
-		cols = newColumns(fmt.Sprintf("Information for Consumer %s > %s created %s", state.Stream, state.Name, state.Created.Local().Format(time.RFC3339)))
+		cols = newColumnsf("Information for Consumer %s > %s created %s", state.Stream, state.Name, f(state.Created))
 	}
 
 	if !c.showStateOnly {
@@ -1205,7 +1212,11 @@ func (c *consumerCmd) showInfo(config api.ConsumerConfig, state api.ConsumerInfo
 		cols.AddSectionTitle("Cluster Information")
 		cols.AddRow("Name", state.Cluster.Name)
 		cols.AddRowIfNotEmpty("Raft Group", state.Cluster.RaftGroup)
-		cols.AddRow("Leader", state.Cluster.Leader)
+		if state.Cluster.LeaderSince == nil {
+			cols.AddRow("Leader", state.Cluster.Leader)
+		} else {
+			cols.AddRowf("Leader", "%s (%s)", state.Cluster.Leader, f(sinceRefOrNow(state.TimeStamp, *state.Cluster.LeaderSince)))
+		}
 		for _, r := range state.Cluster.Replicas {
 			since := fmt.Sprintf("seen %s ago", f(r.Active))
 			if r.Active == 0 || r.Active == math.MaxInt64 {
@@ -1867,6 +1878,9 @@ func (c *consumerCmd) prepareConfig() (cfg *api.ConsumerConfig, err error) {
 	case len(c.overflowGroups) > 0:
 		cfg.PriorityPolicy = api.PriorityOverflow
 		cfg.PriorityGroups = c.pinnedGroups
+	case len(c.prioritizedGroups) > 0:
+		cfg.PriorityPolicy = api.PriorityPrioritized
+		cfg.PriorityGroups = c.prioritizedGroups
 	}
 
 	cfg.Metadata = iu.RemoveReservedMetadata(cfg.Metadata)
@@ -2107,7 +2121,14 @@ func (c *consumerCmd) checkConfigLevel(cfg *api.ConsumerConfig) error {
 	}
 
 	if len(cfg.PriorityGroups) > 0 || cfg.PriorityPolicy != api.PriorityNone {
-		err := iu.RequireAPILevel(c.mgr, 1, "Consumer Groups requires NATS Server 2.11")
+		var err error
+
+		switch cfg.PriorityPolicy {
+		case api.PriorityPinnedClient:
+			err = iu.RequireAPILevel(c.mgr, 2, "Prioritized Consumer Groups requires NATS Server 2.12")
+		default:
+			err = iu.RequireAPILevel(c.mgr, 1, "Consumer Groups requires NATS Server 2.11")
+		}
 		if err != nil {
 			return err
 		}
@@ -2406,9 +2427,9 @@ func (c *consumerCmd) reportAction(_ *fisk.ParseContext) error {
 
 	leaders := make(map[string]*raftLeader)
 
-	table := iu.NewTableWriter(opts(), fmt.Sprintf("Consumer report for %s with %s consumers", c.stream, f(ss.Consumers)))
-	table.AddHeaders("Consumer", "Mode", "Ack Policy", "Ack Wait", "Ack Pending", "Redelivered", "Unprocessed", "Ack Floor", "Cluster")
-	missing, err := s.EachConsumer(func(cons *jsm.Consumer) {
+	table := iu.NewTableWriterf(opts(), "Consumer report for %s with %s consumers", c.stream, f(ss.Consumers))
+	table.AddHeaders("Consumer", "Mode", "Ack Policy", "Ack Wait", "Ack Pending", "Redelivered", "Unprocessed", "Ack Floor", "API Level", "Cluster")
+	missing, offline, err := s.EachConsumer(func(cons *jsm.Consumer) {
 		cs, err := cons.LatestState()
 		if err != nil {
 			log.Printf("Could not obtain consumer state for %s: %s", cons.Name(), err)
@@ -2430,8 +2451,13 @@ func (c *consumerCmd) reportAction(_ *fisk.ParseContext) error {
 			}
 		}
 
+		apiLevel := cs.Config.Metadata[api.JsMetaRequiredServerLevel]
+		if apiLevel == "" {
+			apiLevel = "0"
+		}
+
 		if c.raw {
-			table.AddRow(cons.Name(), mode, cons.AckPolicy().String(), cons.AckWait(), cs.NumAckPending, cs.NumRedelivered, cs.NumPending, cs.AckFloor.Stream, renderCluster(cs.Cluster))
+			table.AddRow(cons.Name(), mode, cons.AckPolicy().String(), cons.AckWait(), cs.NumAckPending, cs.NumRedelivered, cs.NumPending, cs.AckFloor.Stream, apiLevel, renderCluster(cs.Cluster))
 		} else {
 			unprocessed := "0"
 			if cs.NumPending > 0 {
@@ -2442,7 +2468,7 @@ func (c *consumerCmd) reportAction(_ *fisk.ParseContext) error {
 				unprocessed = fmt.Sprintf("%s / %0.0f%%", f(cs.NumPending), upct)
 			}
 
-			table.AddRow(cons.Name(), mode, cons.AckPolicy().String(), f(cons.AckWait()), f(cs.NumAckPending), f(cs.NumRedelivered), unprocessed, f(cs.AckFloor.Stream), renderCluster(cs.Cluster))
+			table.AddRow(cons.Name(), mode, cons.AckPolicy().String(), f(cons.AckWait()), f(cs.NumAckPending), f(cs.NumRedelivered), unprocessed, f(cs.AckFloor.Stream), apiLevel, renderCluster(cs.Cluster))
 		}
 	})
 	if err != nil {
@@ -2455,14 +2481,14 @@ func (c *consumerCmd) reportAction(_ *fisk.ParseContext) error {
 		renderRaftLeaders(leaders, "Consumers")
 	}
 
-	if len(missing) > 0 {
-		c.renderMissing(os.Stdout, missing)
+	if len(missing) > 0 || len(offline) > 0 {
+		c.renderMissing(os.Stdout, missing, offline)
 	}
 
 	return nil
 }
 
-func (c *consumerCmd) renderMissing(out io.Writer, missing []string) {
+func (c *consumerCmd) renderMissing(out io.Writer, missing []string, offline map[string]string) {
 	toany := func(items []string) (res []any) {
 		for _, i := range items {
 			res = append(res, any(i))
@@ -2473,10 +2499,28 @@ func (c *consumerCmd) renderMissing(out io.Writer, missing []string) {
 	if len(missing) > 0 {
 		fmt.Fprintln(out)
 		sort.Strings(missing)
-		table := iu.NewTableWriter(opts(), "Inaccessible Consumers")
+		table := iu.NewTableWriterf(opts(), "Inaccessible Consumers")
 		iu.SliceGroups(missing, 4, func(names []string) {
 			table.AddRow(toany(names)...)
 		})
 		fmt.Fprint(out, table.Render())
 	}
+
+	// realistically this will never actually be called because CLI will stream info first and any offline consumer
+	//takes the stream offline also but lets assume this might improve in time and so we keep this here
+	if len(offline) > 0 {
+		fmt.Fprintln(out)
+		table := iu.NewTableWriterf(opts(), "Offline Consumers")
+
+		var keys []string
+		for k := range offline {
+			keys = append(keys, k)
+		}
+		sort.Strings(keys)
+
+		for _, k := range keys {
+			table.AddRow(k, offline[k])
+		}
+		fmt.Fprint(out, table.Render())
+	}
 }
