@@ -14,7 +14,6 @@
 package cli
 
 import (
-	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -41,7 +40,7 @@ type kvCommand struct {
 	key                     string
 	val                     string
 	raw                     bool
-	history                 uint64
+	history                 int64
 	ttl                     time.Duration
 	replicas                uint
 	force                   bool
@@ -100,7 +99,7 @@ for an indefinite period or a per-bucket configured TTL.
 	addCreateFlags := func(f *fisk.CmdClause, edit bool) {
 		f.Arg("bucket", "The bucket to act on").Required().StringVar(&c.bucket)
 		f.Flag("description", "A description for the bucket").IsSetByUser(&c.descriptionSet).StringVar(&c.description)
-		f.Flag("history", "How many historic values to keep per key").IsSetByUser(&c.historySet).Default("1").Uint64Var(&c.history)
+		f.Flag("history", "How many historic values to keep per key").IsSetByUser(&c.historySet).Default("1").Validator(iu.Int64RangeValidator(1, 64)).Int64Var(&c.history)
 		if !edit {
 			f.Flag("storage", "Storage backend to use (file, memory)").EnumVar(&c.storage, "file", "f", "memory", "m")
 		}
@@ -187,6 +186,7 @@ for an indefinite period or a per-bucket configured TTL.
 
 	ls := kv.Command("ls", "List available buckets or the keys in a bucket").Alias("list").Action(c.lsAction)
 	ls.Arg("bucket", "The bucket to list the keys").StringVar(&c.bucket)
+	ls.Arg("key", "The key to act on").Default("").StringVar(&c.key)
 	ls.Flag("names", "Show just the bucket names").Short('n').UnNegatableBoolVar(&c.listNames)
 	ls.Flag("verbose", "Show detailed info about the key").Short('v').UnNegatableBoolVar(&c.lsVerbose)
 	ls.Flag("display-value", "Display value in verbose output (has no effect without 'verbose')").UnNegatableBoolVar(&c.lsVerboseDisplayValue)
@@ -202,17 +202,14 @@ func init() {
 
 func (c *kvCommand) parseLimitStrings(_ *fisk.ParseContext) (err error) {
 	if c.maxValueSizeString != "" {
-		c.maxValueSize, err = iu.ParseStringAsBytes(c.maxValueSizeString)
+		c.maxValueSize, err = iu.ParseStringAsBytes(c.maxValueSizeString, 32)
 		if err != nil {
 			return err
 		}
-		if c.maxValueSize > math.MaxInt32 {
-			return fmt.Errorf("max value size %s is too big maximum is %s", f(c.maxValueSize), f(math.MaxInt32))
-		}
 	}
 
 	if c.maxBucketSizeString != "" {
-		c.maxBucketSize, err = iu.ParseStringAsBytes(c.maxBucketSizeString)
+		c.maxBucketSize, err = iu.ParseStringAsBytes(c.maxBucketSizeString, 64)
 		if err != nil {
 			return err
 		}
@@ -248,15 +245,19 @@ func (c *kvCommand) lsBucketKeys() error {
 		return fmt.Errorf("unable to prepare js helper: %s", err)
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	kv, err := js.KeyValue(ctx, c.bucket)
 	if err != nil {
 		return fmt.Errorf("unable to load bucket: %s", err)
 	}
 
-	lister, err := kv.ListKeys(ctx)
+	var lister jetstream.KeyLister
+	//key not empty
+	if c.key != "" {
+		lister, err = kv.ListKeysFiltered(ctx, c.key)
+	} else {
+		lister, err = kv.ListKeys(ctx)
+	}
+
 	if err != nil {
 		return err
 	}
@@ -288,7 +289,7 @@ func (c *kvCommand) displayKeyInfo(kv jetstream.KeyValue, keys jetstream.KeyList
 		return found, errors.New("key value cannot be nil")
 	}
 
-	table := iu.NewTableWriter(opts(), fmt.Sprintf("Contents for bucket '%s'", c.bucket))
+	table := iu.NewTableWriterf(opts(), "Contents for bucket '%s'", c.bucket)
 
 	if c.lsVerboseDisplayValue {
 		table.AddHeaders("Key", "Created", "Delta", "Revision", "Value")
@@ -296,9 +297,6 @@ func (c *kvCommand) displayKeyInfo(kv jetstream.KeyValue, keys jetstream.KeyList
 		table.AddHeaders("Key", "Created", "Delta", "Revision")
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	for keyName := range keys.Keys() {
 		found = true
 		kve, err := kv.Get(ctx, keyName)
@@ -333,7 +331,7 @@ func (c *kvCommand) lsBuckets() error {
 
 	var found []*jsm.Stream
 
-	_, err = mgr.EachStream(nil, func(s *jsm.Stream) {
+	_, _, err = mgr.EachStream(nil, func(s *jsm.Stream) {
 		if s.IsKVBucket() {
 			found = append(found, s)
 		}
@@ -361,7 +359,7 @@ func (c *kvCommand) lsBuckets() error {
 		return info.State.Bytes < jnfo.State.Bytes
 	})
 
-	table := iu.NewTableWriter(opts(), "Key-Value Buckets")
+	table := iu.NewTableWriterf(opts(), "Key-Value Buckets")
 	table.AddHeaders("Bucket", "Description", "Created", "Size", "Values", "Last Update")
 	for _, s := range found {
 		nfo, _ := s.LatestInformation()
@@ -380,9 +378,6 @@ func (c *kvCommand) revertAction(pc *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	history, err := store.History(ctx, c.key)
 	if err != nil {
 		return err
@@ -428,15 +423,12 @@ func (c *kvCommand) historyAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	history, err := store.History(ctx, c.key)
 	if err != nil {
 		return err
 	}
 
-	table := iu.NewTableWriter(opts(), fmt.Sprintf("History for %s > %s", c.bucket, c.key))
+	table := iu.NewTableWriterf(opts(), "History for %s > %s", c.bucket, c.key)
 	table.AddHeaders("Key", "Revision", "Op", "Created", "Length", "Value")
 	for _, r := range history {
 		val := iu.Base64IfNotPrintable(r.Value())
@@ -470,9 +462,6 @@ func (c *kvCommand) compactAction(_ *fisk.ParseContext) error {
 		}
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	return store.PurgeDeletes(ctx)
 }
 
@@ -498,9 +487,6 @@ func (c *kvCommand) deleteAction(pc *fisk.ParseContext) error {
 		}
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	return store.Delete(ctx, c.key)
 }
 
@@ -558,9 +544,6 @@ func (c *kvCommand) addAction(_ *fisk.ParseContext) error {
 		})
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	store, err := js.CreateKeyValue(ctx, cfg)
 	if err != nil {
 		return err
@@ -575,13 +558,11 @@ func (c *kvCommand) editAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	kv, err := js.KeyValue(ctx, c.bucket)
 	if err != nil {
 		return err
 	}
+
 	status, err := kv.Status(ctx)
 	if err != nil {
 		return err
@@ -678,9 +659,6 @@ func (c *kvCommand) getAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	var res jetstream.KeyValueEntry
 	if c.revision > 0 {
 		res, err = store.GetRevision(ctx, c.key, c.revision)
@@ -696,7 +674,7 @@ func (c *kvCommand) getAction(_ *fisk.ParseContext) error {
 		return nil
 	}
 
-	fmt.Printf("%s > %s revision: %d created @ %s\n", res.Bucket(), res.Key(), res.Revision(), res.Created().Format(time.RFC822))
+	fmt.Printf("%s > %s revision: %d created @ %s\n", res.Bucket(), res.Key(), res.Revision(), f(res.Created()))
 	fmt.Println()
 	pv := iu.Base64IfNotPrintable(res.Value())
 	lpv := len(pv)
@@ -723,9 +701,6 @@ func (c *kvCommand) putAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	_, err = store.Put(ctx, c.key, val)
 	if err != nil {
 		return err
@@ -747,9 +722,6 @@ func (c *kvCommand) createAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	if c.keyTTL > 0 {
 		_, err = store.Create(ctx, c.key, val, jetstream.KeyTTL(c.keyTTL))
 	} else {
@@ -775,9 +747,6 @@ func (c *kvCommand) updateAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	_, err = store.Update(ctx, c.key, val, c.revision)
 	if err != nil {
 		return err
@@ -822,9 +791,6 @@ func (c *kvCommand) loadBucket() (*nats.Conn, jetstream.JetStream, jetstream.Key
 		}
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	store, err := js.KeyValue(ctx, c.bucket)
 	if err != nil {
 		return nil, nil, nil, err
@@ -869,8 +835,6 @@ func (c *kvCommand) watchAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx := context.Background()
-
 	var opts []jetstream.WatchOpt
 	if !c.includeDeletes {
 		opts = append(opts, jetstream.IgnoreDeletes())
@@ -925,9 +889,6 @@ func (c *kvCommand) purgeAction(_ *fisk.ParseContext) error {
 		}
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	if c.keyTTL > 0 {
 		return store.Purge(ctx, c.key, jetstream.PurgeTTL(c.keyTTL))
 	}
@@ -953,16 +914,10 @@ func (c *kvCommand) rmBucketAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	return js.DeleteKeyValue(ctx, c.bucket)
 }
 
 func (c *kvCommand) showStatus(store jetstream.KeyValue) error {
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	status, err := store.Status(ctx)
 	if err != nil {
 		return err
@@ -973,13 +928,13 @@ func (c *kvCommand) showStatus(store jetstream.KeyValue) error {
 		nfo = status.(*jetstream.KeyValueBucketStatus).StreamInfo()
 	}
 
-	cols := newColumns("")
+	cols := newColumnsf("")
 	defer cols.Frender(os.Stdout)
 
 	if nfo == nil {
 		cols.SetHeading(fmt.Sprintf("Information for Key-Value Store Bucket %s", status.Bucket()))
 	} else {
-		cols.SetHeading(fmt.Sprintf("Information for Key-Value Store Bucket %s created %s", status.Bucket(), nfo.Created.Local().Format(time.RFC3339)))
+		cols.SetHeading(fmt.Sprintf("Information for Key-Value Store Bucket %s created %s", status.Bucket(), f(nfo.Created)))
 	}
 
 	cols.AddSectionTitle("Configuration")
