@@ -147,7 +147,7 @@ func init() {
 
 func (c *objCommand) parseLimitStrings(_ *fisk.ParseContext) (err error) {
 	if c.maxBucketSizeString != "" {
-		c.maxBucketSize, err = iu.ParseStringAsBytes(c.maxBucketSizeString)
+		c.maxBucketSize, err = iu.ParseStringAsBytes(c.maxBucketSizeString, 64)
 		if err != nil {
 			return err
 		}
@@ -162,9 +162,6 @@ func (c *objCommand) watchAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	w, err := obj.Watch(ctx, jetstream.IncludeHistory())
 	if err != nil {
 		return err
@@ -201,9 +198,6 @@ func (c *objCommand) sealAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	err = obj.Seal(ctx)
 	if err != nil {
 		return err
@@ -220,9 +214,6 @@ func (c *objCommand) delAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	if c.file != "" {
 		if !c.force {
 
@@ -268,9 +259,6 @@ func (c *objCommand) delAction(_ *fisk.ParseContext) error {
 			return err
 		}
 
-		ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-		defer cancel()
-
 		return js.DeleteObjectStore(ctx, c.bucket)
 	}
 }
@@ -285,9 +273,6 @@ func (c *objCommand) infoAction(_ *fisk.ParseContext) error {
 		return c.showBucketInfo(obj)
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	nfo, err := obj.GetInfo(ctx, c.file)
 	if err != nil {
 		return err
@@ -299,9 +284,6 @@ func (c *objCommand) infoAction(_ *fisk.ParseContext) error {
 }
 
 func (c *objCommand) showBucketInfo(store jetstream.ObjectStore) error {
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	status, err := store.Status(ctx)
 	if err != nil {
 		return err
@@ -312,17 +294,17 @@ func (c *objCommand) showBucketInfo(store jetstream.ObjectStore) error {
 		nfo = status.(*jetstream.ObjectBucketStatus).StreamInfo()
 	}
 
-	cols := newColumns("")
+	cols := newColumnsf("")
 	defer cols.Frender(os.Stdout)
 
 	if nfo == nil {
 		cols.SetHeading(fmt.Sprintf("Information for Object Store Bucket %s", status.Bucket()))
 	} else {
-		cols.SetHeading(fmt.Sprintf("Information for Object Store Bucket %s created %s", status.Bucket(), nfo.Created.Local().Format(time.RFC3339)))
+		cols.SetHeading(fmt.Sprintf("Information for Object Store Bucket %s created %s", status.Bucket(), f(nfo.Created)))
 	}
 
 	cols.AddSectionTitle("Configuration")
-	cols.AddRowf("Bucket Name", status.Bucket())
+	cols.AddRow("Bucket Name", status.Bucket())
 	cols.AddRowIfNotEmpty("Description", status.Description())
 	cols.AddRow("Replicas", status.Replicas())
 	if status.TTL() == 0 {
@@ -362,7 +344,7 @@ func (c *objCommand) showObjectInfo(nfo *jetstream.ObjectInfo) {
 	digest := strings.SplitN(nfo.Digest, "=", 2)
 	digestBytes, _ := base64.URLEncoding.DecodeString(digest[1])
 
-	cols := newColumns(fmt.Sprintf("Object information for %s > %s", nfo.Bucket, nfo.Name))
+	cols := newColumnsf("Object information for %s > %s", nfo.Bucket, nfo.Name)
 	defer cols.Frender(os.Stdout)
 
 	if nfo.Description != "" {
@@ -391,7 +373,7 @@ func (c *objCommand) listBuckets() error {
 	}
 
 	var found []*jsm.Stream
-	_, err = mgr.EachStream(nil, func(s *jsm.Stream) {
+	_, _, err = mgr.EachStream(nil, func(s *jsm.Stream) {
 		if s.IsObjectBucket() {
 			found = append(found, s)
 		}
@@ -419,7 +401,7 @@ func (c *objCommand) listBuckets() error {
 		return info.State.Bytes < jnfo.State.Bytes
 	})
 
-	table := iu.NewTableWriter(opts(), "Object Store Buckets")
+	table := iu.NewTableWriterf(opts(), "Object Store Buckets")
 	table.AddHeaders("Bucket", "Description", "Created", "Size", "Last Update")
 	for _, s := range found {
 		nfo, _ := s.LatestInformation()
@@ -442,9 +424,6 @@ func (c *objCommand) lsAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	contents, err := obj.List(ctx)
 	if err != nil {
 		return err
@@ -462,11 +441,11 @@ func (c *objCommand) lsAction(_ *fisk.ParseContext) error {
 		return nil
 	}
 
-	table := iu.NewTableWriter(opts(), "Bucket Contents")
+	table := iu.NewTableWriterf(opts(), "Bucket Contents")
 	table.AddHeaders("Name", "Size", "Time")
 
 	for _, i := range contents {
-		table.AddRow(i.Name, humanize.IBytes(i.Size), i.ModTime.Format(time.RFC3339))
+		table.AddRow(i.Name, humanize.IBytes(i.Size), f(i.ModTime))
 	}
 
 	fmt.Println(table.Render())
@@ -489,9 +468,6 @@ func (c *objCommand) putAction(_ *fisk.ParseContext) error {
 		return fmt.Errorf("--name is required when reading from stdin")
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	nfo, err := obj.GetInfo(ctx, name)
 	if err == nil && !nfo.Deleted && !c.force {
 		c.showObjectInfo(nfo)
@@ -578,7 +554,7 @@ func (c *objCommand) getAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	res, err := obj.Get(context.Background(), c.file)
+	res, err := obj.Get(ctx, c.file)
 	if err != nil {
 		return err
 	}
@@ -686,9 +662,6 @@ func (c *objCommand) addAction(_ *fisk.ParseContext) error {
 		placement.Tags = c.placementTags
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	obj, err := js.CreateObjectStore(ctx, jetstream.ObjectStoreConfig{
 		Bucket:      c.bucket,
 		Description: c.description,
@@ -713,13 +686,11 @@ func (c *objCommand) editAction(_ *fisk.ParseContext) error {
 		return err
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	os, err := js.ObjectStore(ctx, c.bucket)
 	if err != nil {
 		return err
 	}
+
 	status, err := os.Status(ctx)
 	if err != nil {
 		return err
@@ -802,9 +773,6 @@ func (c *objCommand) loadBucket() (*nats.Conn, jetstream.JetStream, jetstream.Ob
 		}
 	}
 
-	ctx, cancel := context.WithTimeout(ctx, opts().Timeout)
-	defer cancel()
-
 	store, err := js.ObjectStore(ctx, c.bucket)
 	if err != nil {
 		return nil, nil, nil, err
