@@ -23,6 +23,7 @@ import (
 	"syscall"
 	"time"
 
+	"github.com/nats-io/natscli/internal/sysclient"
 	iu "github.com/nats-io/natscli/internal/util"
 
 	"github.com/choria-io/fisk"
@@ -59,6 +60,8 @@ type SrvReportCmd struct {
 	consumer                string
 	watchInterval           int
 	nc                      *nats.Conn
+	apiLevel                uint
+	all                     bool
 }
 
 type srvReportAccountInfo struct {
@@ -101,7 +104,7 @@ func configureServerReportCommand(srv *fisk.CmdClause) {
 	conns.Flag("top", "Limit results to the top results").Default("1000").IntVar(&c.topk)
 	conns.Flag("subject", "Limits responses only to those connections with matching subscription interest").StringVar(&c.subject)
 	conns.Flag("username", "Limits responses only to those connections for a specific authentication username").StringVar(&c.user)
-	conns.Flag("state", "Limits responses only to those connections that are in a specific state (open, closed, all)").PlaceHolder("STATE").Default("open").EnumVar(&c.stateFilter, "open", "closed", "all")
+	conns.Flag("state", "Limits responses only to those connections that are in a specific state (open, closed, all)").Default("open").EnumVar(&c.stateFilter, "open", "closed", "all")
 	conns.Flag("closed-reason", "Filter results based on a closed reason").PlaceHolder("REASON").StringVar(&c.filterReason)
 	conns.Flag("filter", "Expression based filter for connections").StringVar(&c.filterExpression)
 	addFilterOpts(conns)
@@ -149,6 +152,11 @@ func configureServerReportCommand(srv *fisk.CmdClause) {
 	routes.Arg("limit", "Limit the responses to a certain amount of servers").IntVar(&c.waitFor)
 	routes.Flag("sort", "Sort by a specific property (server,cluster,name,account,subs,in-bytes,out-bytes)").EnumVar(&c.sort, "server", "cluster", "name", "account", "subs", "in-bytes", "out-bytes")
 	addFilterOpts(routes)
+
+	reportCmd := report.Command("downgrade", "List assets incompatible with the specified API level").Action(c.downgradeCheckAction)
+	reportCmd.Arg("api", "Target API level to check compatibility against").Required().UintVar(&c.apiLevel)
+	reportCmd.Flag("json", "Output the downgrade report in JSON format").UnNegatableBoolVar(&c.json)
+	reportCmd.Flag("all", "Include consumers whose associated streams are incompatible with the selected API level").UnNegatableBoolVar(&c.all)
 }
 
 func (c *SrvReportCmd) withWatcher(fn func(*fisk.ParseContext) error) func(*fisk.ParseContext) error {
@@ -246,7 +254,7 @@ func (c *SrvReportCmd) reportLeafs(_ *fisk.ParseContext) error {
 		}
 	})
 
-	tbl := iu.NewTableWriter(opts(), "Leafnode Report")
+	tbl := iu.NewTableWriterf(opts(), "Leafnode Report")
 	tbl.AddHeaders("Server", "Name", "Account", "Address", "RTT", "Msgs In", "Msgs Out", "Bytes In", "Bytes Out", "Subs", "Compressed", "Spoke")
 
 	for _, lz := range leafs {
@@ -325,7 +333,7 @@ func (c *SrvReportCmd) reportHealth(_ *fisk.ParseContext) error {
 		return c.boolReverse(servers[i].Server.Name < servers[j].Server.Name)
 	})
 
-	tbl := iu.NewTableWriter(opts(), "Health Report")
+	tbl := iu.NewTableWriterf(opts(), "Health Report")
 	tbl.AddHeaders("Server", "Cluster", "Domain", "Status", "Type", "Error")
 
 	var ok, notok, totalErrors int
@@ -433,7 +441,7 @@ func (c *SrvReportCmd) reportGateway(_ *fisk.ParseContext) error {
 		}
 	})
 
-	tbl := iu.NewTableWriter(opts(), "Super Cluster Report")
+	tbl := iu.NewTableWriterf(opts(), "Super Cluster Report")
 	tbl.AddHeaders("Server", "Name", "Port", "Kind", "Connection", "ID", "Uptime", "RTT", "Bytes", "Accounts")
 
 	var lastServer, lastName, lastDirection string
@@ -616,7 +624,7 @@ func (c *SrvReportCmd) reportRoute(_ *fisk.ParseContext) error {
 		return c.boolReverse(wasSorted)
 	})
 
-	tbl := iu.NewTableWriter(opts(), "Cluster Report")
+	tbl := iu.NewTableWriterf(opts(), "Cluster Report")
 	tbl.AddHeaders("Server", "Cluster", "Name", "Account", "Address", "ID", "Uptime", "RTT", "Subs", "Bytes In", "Bytes Out")
 
 	var lastServer, lastCluster, lastRemote string
@@ -755,7 +763,6 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 	var (
 		names               []string
 		jszResponses        []*server.ServerAPIJszResponse
-		apiErrTotal         uint64
 		apiTotal            uint64
 		pendingTotal        int
 		memoryTotal         uint64
@@ -812,8 +819,6 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 			return c.boolReverse(jszResponses[i].Data.JetStreamStats.Store < jszResponses[j].Data.JetStreamStats.Store)
 		case "api":
 			return c.boolReverse(jszResponses[i].Data.JetStreamStats.API.Total < jszResponses[j].Data.JetStreamStats.API.Total)
-		case "err":
-			return c.boolReverse(jszResponses[i].Data.JetStreamStats.API.Errors < jszResponses[j].Data.JetStreamStats.API.Errors)
 		default:
 			if jszResponses[i].Server.Cluster != jszResponses[j].Server.Cluster {
 				return c.boolReverse(jszResponses[i].Server.Cluster < jszResponses[j].Server.Cluster)
@@ -839,7 +844,7 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 
 	var table *iu.Table
 	if c.account != "" {
-		table = iu.NewTableWriter(opts(), fmt.Sprintf("JetStream Summary for Account %s", c.account))
+		table = iu.NewTableWriterf(opts(), "JetStream Summary for Account %s", c.account)
 	} else {
 		table = iu.NewTableWriter(opts(), "JetStream Summary")
 	}
@@ -848,7 +853,7 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 	if renderDomain {
 		hdrs = append(hdrs, "Domain")
 	}
-	hdrs = append(hdrs, "Streams", "Consumers", "Messages", "Bytes", "Memory", "File", "API Req", "API Err")
+	hdrs = append(hdrs, "Streams", "Consumers", "Messages", "Bytes", "Memory", "File", "API Req")
 	if renderPending {
 		hdrs = append(hdrs, "Pending")
 	}
@@ -865,7 +870,6 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 			doAccountStats = true
 		}
 
-		apiErrTotal += jss.API.Errors
 		apiTotal += jss.API.Total
 		memoryTotal += jss.Memory
 		storeTotal += jss.Store
@@ -916,11 +920,7 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 		if renderDomain {
 			row = append(row, js.Data.Config.Domain)
 		}
-		errCol := f(jss.API.Errors)
-		if jss.API.Total > 0 && jss.API.Errors > 0 {
-			errRate := float64(jss.API.Errors) * 100 / float64(jss.API.Total)
-			errCol += " / " + f(errRate) + "%"
-		}
+
 		row = append(row,
 			f(rStreams),
 			f(rConsumers),
@@ -929,7 +929,6 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 			humanize.IBytes(jss.Memory),
 			humanize.IBytes(jss.Store),
 			f(jss.API.Total),
-			errCol,
 		)
 		if renderPending {
 			row = append(row, rPending)
@@ -942,7 +941,7 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 	if renderDomain {
 		row = append(row, "")
 	}
-	row = append(row, f(streamsTotal), f(consumersTotal), f(msgsTotal), humanize.IBytes(bytesTotal), humanize.IBytes(memoryTotal), humanize.IBytes(storeTotal), f(apiTotal), f(apiErrTotal))
+	row = append(row, f(streamsTotal), f(consumersTotal), f(msgsTotal), humanize.IBytes(bytesTotal), humanize.IBytes(memoryTotal), humanize.IBytes(storeTotal), f(apiTotal))
 	if renderPending {
 		row = append(row, pendingTotal)
 	}
@@ -984,7 +983,7 @@ func (c *SrvReportCmd) reportJetStream(_ *fisk.ParseContext) error {
 			cNames = names
 		}
 
-		table := iu.NewTableWriter(opts(), "RAFT Meta Group Information")
+		table := iu.NewTableWriterf(opts(), "RAFT Meta Group Information")
 		table.AddHeaders("Connection Name", "ID", "Leader", "Current", "Online", "Active", "Lag")
 		for i, replica := range cluster.Replicas {
 			leader := ""
@@ -1077,7 +1076,7 @@ func (c *SrvReportCmd) reportAccount(_ *fisk.ParseContext) error {
 		return nil
 	}
 
-	table := iu.NewTableWriter(opts(), fmt.Sprintf("%d Accounts Overview", len(accounts)))
+	table := iu.NewTableWriterf(opts(), "%d Accounts Overview", len(accounts))
 	table.AddHeaders("Account", "Connections", "In Msgs", "Out Msgs", "In Bytes", "Out Bytes", "Subs")
 
 	for _, acct := range accounts {
@@ -1193,7 +1192,7 @@ func (c *SrvReportCmd) renderConnections(report []connInfo) {
 		limit = c.topk
 	}
 
-	table := iu.NewTableWriter(opts(), fmt.Sprintf("Top %d Connections out of %s by %s", limit, f(total), c.sort))
+	table := iu.NewTableWriterf(opts(), "Top %d Connections out of %s by %s", limit, f(total), c.sort)
 	showReason := c.stateFilter == "closed" || c.stateFilter == "all"
 	headers := []any{"CID", "Name", "Server", "Cluster", "IP", "Account", "Uptime", "In Msgs", "Out Msgs", "In Bytes", "Out Bytes", "Subs"}
 	if showReason {
@@ -1280,7 +1279,7 @@ func (c *SrvReportCmd) renderConnections(report []connInfo) {
 			return servers[serverNames[i]].conns < servers[serverNames[j]].conns
 		})
 
-		table := iu.NewTableWriter(opts(), "Connections per server")
+		table := iu.NewTableWriterf(opts(), "Connections per server")
 		table.AddHeaders("Server", "Cluster", "Connections")
 		sort.Slice(serverNames, func(i, j int) bool {
 			return servers[serverNames[i]].conns < servers[serverNames[j]].conns
@@ -1534,9 +1533,131 @@ func (c *SrvReportCmd) isFiltered() bool {
 
 func (c *SrvReportCmd) reqFilter() server.EventFilterOptions {
 	return server.EventFilterOptions{
-		Domain:  opts().Config.JSDomain(),
-		Name:    c.server,
-		Cluster: c.cluster,
-		Tags:    c.tags,
+		Domain:     opts().Config.JSDomain(),
+		Name:       c.server,
+		Cluster:    c.cluster,
+		Tags:       c.tags,
+		ExactMatch: true,
+	}
+}
+
+type jsDowngradeAsset struct {
+	Streams   []jsDowngradeStreamAsset   `json:"streams,omitempty"`
+	Consumers []jsDowngradeConsumerAsset `json:"consumers,omitempty"`
+}
+
+type jsDowngradeStreamAsset struct {
+	Account  string `json:"account"`
+	Name     string `json:"name"`
+	APILevel uint   `json:"api_level"`
+}
+
+type jsDowngradeConsumerAsset struct {
+	Account  string `json:"account"`
+	Name     string `json:"name"`
+	Stream   string `json:"stream"`
+	APILevel uint   `json:"api_level"`
+}
+
+func (c *SrvReportCmd) downgradeCheckAction(_ *fisk.ParseContext) error {
+	nc, err := newNatsConn("", natsOpts()...)
+	if err != nil {
+		return fmt.Errorf("connection setup failed: %v", err)
+	}
+	defer nc.Close()
+
+	if !c.json {
+		fmt.Println("Obtaining JetStream Asset information")
+	}
+
+	activeServers, err := currentActiveServers(nc)
+	if err != nil {
+		return err
+	}
+	if activeServers == 0 {
+		return fmt.Errorf("failed to find any active servers before timeout expired")
+	}
+
+	sys := sysclient.New(nc, opts().Trace)
+	accounts, err := sys.CollectClusterAccounts(opts().Timeout, activeServers)
+	if err != nil {
+		return fmt.Errorf("JSZ fetch failed: %v", err)
+	}
+
+	var as jsDowngradeAsset
+	for _, acc := range accounts {
+		for _, s := range acc.Streams {
+			streamApiLevel := iu.ParseApiLevel(s.Config.Metadata["_nats.req.level"])
+			incompatibleStream := c.apiLevel < streamApiLevel
+
+			if incompatibleStream {
+				as.Streams = append(as.Streams, jsDowngradeStreamAsset{
+					Account:  acc.Name,
+					Name:     s.Name,
+					APILevel: streamApiLevel,
+				})
+			}
+
+			sort.Slice(s.Consumer, func(i, j int) bool {
+				return s.Consumer[i].Name < s.Consumer[j].Name
+			})
+
+			for _, con := range s.Consumer {
+				consumerApiLevel := iu.ParseApiLevel(con.Config.Metadata["_nats.req.level"])
+				if c.apiLevel < consumerApiLevel || (c.all && incompatibleStream) {
+					displayStream := s.Name
+					if c.all && incompatibleStream {
+						displayStream += "*"
+					}
+					as.Consumers = append(as.Consumers, jsDowngradeConsumerAsset{
+						Account:  acc.Name,
+						Name:     con.Name,
+						Stream:   displayStream,
+						APILevel: consumerApiLevel,
+					})
+				}
+			}
+		}
+	}
+
+	c.renderDowngrade(as)
+	return nil
+}
+
+func (c *SrvReportCmd) renderDowngrade(as jsDowngradeAsset) {
+	if !c.json {
+		c.printDowngradeReport(as)
+		return
+	}
+
+	if err := iu.PrintJSON(as); err != nil {
+		fmt.Printf("unable to generate json output: %s\n", err)
+	}
+}
+
+func (c *SrvReportCmd) printDowngradeReport(as jsDowngradeAsset) {
+	empty := true
+	if len(as.Streams) > 0 {
+		empty = false
+		streamsTable := iu.NewTableWriterf(opts(), "Assets: Streams")
+		streamsTable.AddHeaders("Account", "Stream", "Required API level")
+		for _, s := range as.Streams {
+			streamsTable.AddRow(s.Account, s.Name, s.APILevel)
+		}
+		fmt.Println(streamsTable.Render())
+	}
+
+	if len(as.Consumers) > 0 {
+		empty = false
+		consumersTable := iu.NewTableWriterf(opts(), "Assets: Consumers")
+		consumersTable.AddHeaders("Account", "Stream", "Consumer", "Required API level")
+		for _, c := range as.Consumers {
+			consumersTable.AddRow(c.Account, c.Stream, c.Name, c.APILevel)
+		}
+		fmt.Println(consumersTable.Render())
+	}
+
+	if empty {
+		fmt.Println("All assets are compatible with the specified API level.")
 	}
 }
