@@ -46,6 +46,8 @@ import (
 	"github.com/nats-io/natscli/options"
 )
 
+var ErrContextNotFound = errors.New("context not found")
+
 func selectConsumer(mgr *jsm.Manager, stream string, consumer string, force bool) (string, *jsm.Consumer, error) {
 	if consumer != "" {
 		c, err := mgr.LoadConsumer(stream, consumer)
@@ -188,7 +190,7 @@ func askOneBytes(prompt string, dflt string, help string, required string) (int6
 			val = "0"
 		}
 
-		i, err := iu.ParseStringAsBytes(val)
+		i, err := iu.ParseStringAsBytes(val, 64)
 		if err != nil {
 			return 0, err
 		}
@@ -241,9 +243,18 @@ func natsOpts() []nats.Option {
 	return append(copts, []nats.Option{
 		nats.Name(connectionName),
 		nats.MaxReconnects(-1),
+		nats.CustomReconnectDelay(func(attempts int) time.Duration {
+			d := iu.DefaultBackoff.Duration(attempts)
+
+			if opts().Trace {
+				log.Printf(">>> Setting reconnect delay to %v", d)
+			}
+
+			return d
+		}),
 		nats.ConnectHandler(func(conn *nats.Conn) {
 			if opts().Trace {
-				log.Printf(">>> Connected to %s", conn.ConnectedUrlRedacted())
+				log.Printf(">>> Connected to %s (%s)", conn.ConnectedUrlRedacted(), conn.ConnectedAddr())
 			}
 		}),
 		nats.DiscoveredServersHandler(func(conn *nats.Conn) {
@@ -257,7 +268,14 @@ func natsOpts() []nats.Option {
 			}
 		}),
 		nats.ReconnectHandler(func(nc *nats.Conn) {
-			log.Printf("Reconnected [%s]", nc.ConnectedUrl())
+			if opts().Trace {
+				log.Printf("Reconnected to %s (%s)", nc.ConnectedUrlRedacted(), nc.ConnectedAddr())
+			}
+		}),
+		nats.ReconnectErrHandler(func(conn *nats.Conn, err error) {
+			if err != nil {
+				log.Printf("Reconnect error: %s", err)
+			}
 		}),
 		nats.ErrorHandler(func(nc *nats.Conn, _ *nats.Subscription, err error) {
 			url := nc.ConnectedUrl()
@@ -293,6 +311,40 @@ func jetstreamOpts() []jetstream.JetStreamOpt {
 	return res
 }
 
+func newJetStreamWithOptions(nc *nats.Conn, opts *options.Options) (jetstream.JetStream, error) {
+	var js jetstream.JetStream
+	var err error
+	jsops := []jetstream.JetStreamOpt{
+		jetstream.WithDefaultTimeout(opts.Timeout),
+	}
+
+	if opts.Trace {
+		ct := &jetstream.ClientTrace{
+			RequestSent: func(subj string, payload []byte) {
+				log.Printf(">>> %s\n%s\n\n", subj, string(payload))
+			},
+			ResponseReceived: func(subj string, payload []byte, hdr nats.Header) {
+				log.Printf("<<< %s: %s", subj, string(payload))
+			},
+		}
+		jsops = append(jsops, jetstream.WithClientTrace(ct))
+	}
+
+	switch {
+	case opts.Config.JSDomain() != "":
+		js, err = jetstream.NewWithDomain(nc, opts.Config.JSDomain(), jsops...)
+	case opts.Config.JSAPIPrefix() != "":
+		js, err = jetstream.NewWithAPIPrefix(nc, opts.Config.JSAPIPrefix(), jsops...)
+	default:
+		js, err = jetstream.New(nc, jsops...)
+	}
+	if err != nil {
+		return nil, err
+	}
+
+	return js, nil
+}
+
 func jsOpts() []nats.JSOpt {
 	opts := opts()
 	jso := []nats.JSOpt{
@@ -516,6 +568,9 @@ func loadContext(softFail bool) error {
 	}
 
 	if err != nil && softFail {
+		if !natscontext.IsKnown(opts.CfgCtx) {
+			return ErrContextNotFound
+		}
 		opts.Config, err = natscontext.New(opts.CfgCtx, false, ctxOpts...)
 	}
 
@@ -721,7 +776,7 @@ type raftLeader struct {
 }
 
 func renderRaftLeaders(leaders map[string]*raftLeader, grpTitle string) {
-	table := iu.NewTableWriter(opts(), "RAFT Leader Report")
+	table := iu.NewTableWriterf(opts(), "RAFT Leader Report")
 	table.AddHeaders("Server", "Cluster", grpTitle, "Distribution")
 
 	var llist []*raftLeader
