@@ -105,6 +105,16 @@ func prepareHelper(servers string) (*nats.Conn, *jsm.Manager, error) {
 	return nc, mgr, nil
 }
 
+func createDefaultTestStream(t *testing.T, mgr *jsm.Manager, replicas int, opts ...jsm.StreamOption) {
+	t.Helper()
+	opts = append(opts, jsm.Replicas(replicas), jsm.Subjects("TEST_STREAM.*"))
+
+	_, err := mgr.NewStream("TEST_STREAM", opts...)
+	if err != nil {
+		t.Fatalf("unable to create stream: %s", err)
+	}
+}
+
 func setupJStreamTest(t *testing.T) (srv *server.Server, nc *nats.Conn, mgr *jsm.Manager) {
 	t.Helper()
 
@@ -148,11 +158,27 @@ func setupJStreamTest(t *testing.T) (srv *server.Server, nc *nats.Conn, mgr *jsm
 
 	return srv, nc, mgr
 }
+
+func withNatsServer(t *testing.T, cb func(*testing.T, *server.Server, *nats.Conn) error) {
+	t.Helper()
+	createServersWithCallback(t, 1, false, cb)
+}
+
+func withJSServer(t *testing.T, cb func(*testing.T, *server.Server, *nats.Conn, *jsm.Manager) error) {
+	t.Helper()
+	createServersWithCallback(t, 1, true, cb)
+}
+
 func withJSCluster(t *testing.T, cb func(*testing.T, []*server.Server, *nats.Conn, *jsm.Manager) error) {
 	t.Helper()
 	if runtime.GOOS == "windows" {
 		t.Skip("Skipping on Windows due to GitHub Actions resource constraints")
 	}
+	createServersWithCallback(t, 3, true, cb)
+}
+
+func createServersWithCallback(t *testing.T, serverCount int, jsEnabled bool, cb any) {
+	t.Helper()
 
 	d, err := os.MkdirTemp("", "jstest")
 	if err != nil {
@@ -160,40 +186,37 @@ func withJSCluster(t *testing.T, cb func(*testing.T, []*server.Server, *nats.Con
 	}
 	defer os.RemoveAll(d)
 
-	var (
-		servers []*server.Server
-	)
-
+	var servers []*server.Server
 	sysAcc := server.NewAccount("SYS")
 
-	for i := 1; i <= 3; i++ {
+	var routes []*url.URL
+	for i := 1; i <= serverCount; i++ {
+		routes = append(routes, &url.URL{Host: fmt.Sprintf("localhost:%d", 12000+i)})
+	}
+
+	for i := 1; i <= serverCount; i++ {
 		opts := &server.Options{
-			JetStream:  true,
-			StoreDir:   filepath.Join(d, fmt.Sprintf("s%d", i)),
-			Port:       -1,
-			Host:       "localhost",
-			ServerName: fmt.Sprintf("s%d", i),
-			LogFile:    filepath.Join(d, fmt.Sprintf("s%d.log", i)),
-			Cluster: server.ClusterOpts{
+			JetStream:     jsEnabled,
+			StoreDir:      filepath.Join(d, fmt.Sprintf("s%d", i)),
+			Port:          -1,
+			Host:          "localhost",
+			ServerName:    fmt.Sprintf("s%d", i),
+			LogFile:       filepath.Join(d, fmt.Sprintf("s%d.log", i)),
+			Routes:        routes,
+			SystemAccount: "SYS",
+			Accounts:      []*server.Account{sysAcc},
+			Users: []*server.User{{
+				Username: "sys",
+				Password: "pass",
+				Account:  sysAcc,
+			}},
+		}
+
+		if serverCount > 1 {
+			opts.Cluster = server.ClusterOpts{
 				Name: "TEST",
 				Port: 12000 + i,
-			},
-			Routes: []*url.URL{
-				{Host: "localhost:12001"},
-				{Host: "localhost:12002"},
-				{Host: "localhost:12003"},
-			},
-			SystemAccount: "SYS",
-			Accounts: []*server.Account{
-				sysAcc,
-			},
-			Users: []*server.User{
-				{
-					Username: "sys",
-					Password: "pass",
-					Account:  sysAcc,
-				},
-			},
+			}
 		}
 
 		s, err := server.NewServer(opts)
@@ -205,15 +228,12 @@ func withJSCluster(t *testing.T, cb func(*testing.T, []*server.Server, *nats.Con
 		if !s.ReadyForConnections(10 * time.Second) {
 			t.Errorf("nats server %d did not start", i)
 		}
-		defer func() {
-			s.Shutdown()
-		}()
-
+		defer s.Shutdown()
 		servers = append(servers, s)
 	}
 
-	if len(servers) != 3 {
-		t.Fatalf("servers did not start")
+	if len(servers) != serverCount {
+		t.Fatalf("not all servers started: expected %d, got %d", serverCount, len(servers))
 	}
 
 	nc, err := nats.Connect(servers[0].ClientURL(), nats.UseOldRequestStyle())
@@ -222,9 +242,53 @@ func withJSCluster(t *testing.T, cb func(*testing.T, []*server.Server, *nats.Con
 	}
 	defer nc.Close()
 
-	mgr, err := jsm.New(nc, jsm.WithTimeout(5*time.Second))
-	if err != nil {
-		t.Fatalf("manager creation failed: %s", err)
+	var mgr *jsm.Manager
+	if jsEnabled {
+		mgr, err = jsm.New(nc, jsm.WithTimeout(5*time.Second))
+		if err != nil {
+			t.Fatalf("manager creation failed: %s", err)
+		}
+	}
+
+	var callback func() error
+
+	switch typed := cb.(type) {
+	case func(t *testing.T, srv *server.Server, nc *nats.Conn) error:
+		if serverCount != 1 {
+			t.Fatal("single server callback provided but serverCount != 1")
+		}
+		callback = func() error {
+			return typed(t, servers[0], nc)
+		}
+
+	case func(t *testing.T, srv *server.Server, nc *nats.Conn, mgr *jsm.Manager) error:
+		if !jsEnabled {
+			t.Fatal("jetstream callback used but jsEnabled is false")
+		}
+		if serverCount != 1 {
+			t.Fatal("single jetstream server callback provided but serverCount != 1")
+		}
+		callback = func() error {
+			return typed(t, servers[0], nc, mgr)
+		}
+
+	case func(t *testing.T, srvs []*server.Server, nc *nats.Conn, mgr *jsm.Manager) error:
+		if !jsEnabled {
+			t.Fatal("jetstream callback used but jsEnabled is false")
+		}
+		callback = func() error {
+			return typed(t, servers, nc, mgr)
+		}
+
+	default:
+		t.Fatalf("unsupported callback signature")
+	}
+
+	if !jsEnabled {
+		if err := callback(); err != nil {
+			t.Fatal(err)
+		}
+		return
 	}
 
 	ctx, cancel := context.WithTimeout(context.Background(), 30*time.Second)
@@ -235,20 +299,17 @@ func withJSCluster(t *testing.T, cb func(*testing.T, []*server.Server, *nats.Con
 	for {
 		select {
 		case <-ticker.C:
-			_, err := mgr.JetStreamAccountInfo()
-			if err != nil {
+			if _, err := mgr.JetStreamAccountInfo(); err != nil {
 				continue
 			}
 
-			err = cb(t, servers, nc, mgr)
-
-			if err != nil {
+			if err := callback(); err != nil {
 				t.Fatal(err)
 			}
-
 			return
+
 		case <-ctx.Done():
-			t.Fatalf("jetstream did not become available")
+			t.Fatalf("jetstream did not become available in time")
 		}
 	}
 }
@@ -997,3 +1058,8 @@ func TestCLIMessageRm(t *testing.T) {
 		t.Fatalf("loading delete message did not fail")
 	}
 }
+
+func TestMain(m *testing.M) {
+	os.Setenv("TESTING", "true")
+	m.Run()
+}
